[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1313687.svg)](https://doi.org/10.5281/zenodo.1313687)

# konrad - Radiative-convective equilibrium framework

The goal of ``konrad`` is to provide a simple framework to run
radiative-convective equilibrium (RCE) simulations. It is build in an object
oriented structure to allow simple modifications of the model setup.

## Requirements
``konrad`` requires Python 3.5.1 or higher. The recommended way to get
Python is through [Anaconda](https://www.continuum.io/downloads).
But of course, any other Python distribution is also working.

## Installation
You can use ``pip`` to install the ``konrad`` package
to your Python distribution. On the top directory level, run:
```bash
pip install --editable .
```
